import axios from 'axios'
import { ElMessage } from 'element-plus' // 假设你使用的是 Element Plus

// 判断当前环境
// const isProduction = process.env.NODE_ENV === 'production'
// console.log(process.env.NODE_ENV, isProduction, 'process.env.NODE_ENV')
// const apiBaseUrl = isProduction ? 'https://api.example.com' : 'http://192.168.110.230:9897/cqmz_test/'
const apiBaseUrl = process.env.VUE_APP_API_HOST // 从环境变量中获取 API 基础 URL

// 创建 Axios 实例
const instance = axios.create({
  baseURL: apiBaseUrl, // 你的 API 基础 URL
  timeout: 60000 // 设置超时时间
})

// 请求拦截器
instance.interceptors.request.use(
  config => {
    // 在发送请求之前做些什么，例如添加 token 到请求头
    const token = localStorage.getItem('token')
    if (token) {
      config.headers.Authorization = `Bearer ${token}`
    }
    return config
  },
  error => {
    // 请求错误时做些什么
    return Promise.reject(error)
  }
)

// 响应拦截器
instance.interceptors.response.use(
  response => {
    // 对响应数据做点什么
    return response.data
  },
  error => {
    // 对响应错误做些什么
    if (error.response) {
      switch (error.response.status) {
        case 400:
          ElMessage.error('错误请求')
          break
        case 401:
          ElMessage.error('未授权，请登录')
          // 清除 token 并跳转到登录页面
          localStorage.removeItem('token')
          // router.push('/login');
          break
        case 403:
          ElMessage.error('拒绝访问')
          break
        case 404:
          ElMessage.error(`请求地址出错: ${error.response.config.url}`)
          break
        case 408:
          ElMessage.error('请求超时')
          break
        case 500:
          ElMessage.error('服务器内部错误')
          break
        case 501:
          ElMessage.error('服务未实现')
          break
        case 502:
          ElMessage.error('网关错误')
          break
        case 503:
          ElMessage.error('服务不可用')
          break
        case 504:
          ElMessage.error('网关超时')
          break
        case 505:
          ElMessage.error('HTTP版本不受支持')
          break
        default:
          ElMessage.error(`连接错误：${error.message}`)
      }
    } else if (error.request) {
      ElMessage.error('无法连接到服务器，请检查网络')
    } else {
      ElMessage.error(`错误：${error.message}`)
    }

    return Promise.reject(error)
  }
)

export default instance
